@@ -87,7 +87,7 @@ COMMANDS = [
                 "help": "video ID, clip slug, or URL",
                 "type": str,
             }),
-            (["-w", "--max_workers"], {
+            (["-w", "--max-workers"], {
                 "help": "maximal number of threads for downloading vods "
                         "concurrently (default 20)",
                 "type": int,
@@ -165,7 +165,7 @@ def main():
         return
 
     try:
-        args.func(**args.__dict__)
+        args.func(args)
     except ConsoleError as e:
         print_err(e)
         sys.exit(1)
